#
# spec file for package kglobalacceld6
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global kf6_version 6.0.0
%define qt6_version 6.7.0

%define rname kglobalacceld
%bcond_without released
# Full Plasma 6 version (e.g. 6.0.0)
%{!?_plasma6_bugfix: %define _plasma6_bugfix %{version}}
# Latest ABI-stable Plasma (e.g. 6.0 in KF6, but 6.0.80 in KUF)
%{!?_plasma6_version: %define _plasma6_version %(echo %{_plasma6_bugfix} | awk -F. '{print $1"."$2}')}
Name:           kglobalacceld6
Version:        6.2.5
Release:        1.1
Summary:        Global keyboard shortcut daemon
License:        LGPL-2.0-or-later
URL:            https://www.kde.org
Source:         https://download.kde.org/stable/plasma/%{version}/%{rname}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/plasma/%{version}/%{rname}-%{version}.tar.xz.sig
Source2:        plasma.keyring
%endif
%if 0%{?suse_version} == 1500
# Due to leap being leap, rpmlint rules are obsolete
Source99:       kglobalacceld6-rpmlintrc
%endif
BuildRequires:  fdupes
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  pkgconfig
BuildRequires:  qt6-gui-private-devel >= %{qt6_version}
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6Crash) >= %{kf6_version}
BuildRequires:  cmake(KF6DBusAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6GlobalAccel) >= %{kf6_version}
BuildRequires:  cmake(KF6JobWidgets) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6Service) >= %{kf6_version}
BuildRequires:  cmake(KF6WindowSystem) >= %{kf6_version}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-keysyms)
BuildRequires:  pkgconfig(xcb-record)
BuildRequires:  pkgconfig(xcb-xkb)
Provides:       kglobalaccel5 = %{version}
Obsoletes:      kglobalaccel5 < %{version}

%description
Daemon providing Global Keyboard Shortcut (Accelerator) functionality.

%package -n libKGlobalAccelD6-0
Summary:        KGlobalAccelD library
Recommends:     kglobalacceld6

%description -n libKGlobalAccelD6-0
KGlobalAcceld is a daemon providing Global Keyboard Shortcut (Accelerator)
functionality.
This package provides the kglobalacceld library.

%package devel
Summary:        Global keyboard shortcut daemon: Build Environment
Requires:       libKGlobalAccelD6-0 >= %{_plasma6_bugfix}
Requires:       cmake(Qt6DBus) >= %{qt6_version}
Requires:       cmake(Qt6Widgets) >= %{qt6_version}

%description devel
Daemon providing Global Keyboard Shortcut (Accelerator) functionality.
Development files.

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%fdupes %{buildroot}

%post
%{systemd_user_post plasma-kglobalaccel.service}

%preun
%{systemd_user_preun plasma-kglobalaccel.service}

%postun
# TODO? Drop? systemd_user_postun is a stub in TW
%{systemd_user_postun plasma-kglobalaccel.service}

%ldconfig_scriptlets -n libKGlobalAccelD6-0

%files
%{_kf6_configdir}/autostart/kglobalacceld.desktop
%dir %{_kf6_plugindir}/org.kde.kglobalacceld.platforms
%{_kf6_plugindir}/org.kde.kglobalacceld.platforms/KGlobalAccelDXcb.so
%{_libexecdir}/kglobalacceld
%{_userunitdir}/plasma-kglobalaccel.service

%files -n libKGlobalAccelD6-0
%license LICENSES/*
%{_kf6_libdir}/libKGlobalAccelD.so.*

%files devel
%{_kf6_cmakedir}/KGlobalAccelD/
%{_includedir}/KGlobalAccelD/

%changelog
* Tue Dec 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.5
- Changes since 6.2.4:
  * update version for new release
* Tue Nov 26 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.4
- Changes since 6.2.3:
  * update version for new release
* Tue Nov  5 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.3
- Changes since 6.2.2:
  * update version for new release
* Tue Oct 22 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.2
- Changes since 6.2.1:
  * update version for new release
* Tue Oct 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.1
- Changes since 6.2.0:
  * Revert "trigger modifier-only shortcuts when any modifier is released"
  * update version for new release
* Sat Oct  5 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.0
- Changes since 6.1.90:
  * update version for new release
* Tue Sep 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.1.90
- Changes since 6.1.5:
  * update version for new release
  * plugins/xcb: skip xrecord events when keyboard is grabbed (kde#488268,kde#491315)
  * plugins/xcb: support different event types in xrecord
  * Set up crash handling
  * plugins/xcb: correctly handle multiple modifiers in xrecord
  * plugins/xcb: only handle modifier presses in XRecord (kde#489113)
  * explicitly process invalid keycodes (kde#489001)
  * Add .gitignore file from kglobalaccel repo
  * trigger modifier-only shortcuts when any modifier is released
  * Remove redundant returns - no events are filtered out
  * Prevent high CPU usage due to mass key remappings
  * update version for new release
* Tue Sep 10 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.5
- Changes since 6.1.4:
  * Set up crash handling
  * update version for new release
* Tue Aug  6 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.4
- Changes since 6.1.3:
  * update version for new release
* Tue Jul 16 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.3
- Changes since 6.1.2:
  * explicitly process invalid keycodes (kde#489001)
  * update version for new release
* Tue Jul  2 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.2
- Changes since 6.1.1:
  * update version for new release
* Tue Jun 25 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.1
- Changes since 6.1.0:
  * update version for new release
* Thu Jun 13 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.0
- Changes since 6.0.90:
  * update version for new release
* Sat May 25 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.0.90
- Changes since 6.0.5:
  * update version for new release
  * Add key code sanity check in GlobalShortcutsRegistry::processKey
  * Postpone processing KSycoca to the next event loop cycle
  * Update service-based shortcuts when service database changes (kde#479730,kde#483918)
  * Fix KHotkeys migration (kde#484063)
  * sequencehelpers_p: rename mangleKey to normalizeSequence
  * add tests
  * plugins/xcb: correctly handle modifier-only shortcuts
  * add API for listening to mouse events
  * Enhance modifier-only shortcuts (kde#464805,kde#470256)
  * globalshortcutregistry: refactor
  * globalshortcutsregistry: treat super as meta (kde#481173)
  * Also consider actions when querying for applications with shortcuts (kde#483214)
  * Include all deprecated functions by default (kde#482712)
  * plugins/xcb/kglobalaccel_x11: use new KKeyServer API (kde#478936)
  * globalshortcutsregistry: treat SysReq as Alt+Print (kde#386253)
  * Migrate command shortcuts from khotkeys
  * Drop outdated comment
  * Remove unused function arg
  * Only write non-default shortcuts during migration
  * Apply X-KDE-GlobalShortcutType also in loadFromService
  * Add migration helper to migrate dynamic shortcuts to desktop file based shortcuts
  * Fix old KF5-based desktop entries lingering in kglobalshortcutsrc
* Wed May 22 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.5
- Changes since 6.0.4:
  * update version for new release
  * Postpone processing KSycoca to the next event loop cycle
* Wed Apr 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.4
- Changes since 6.0.3:
  * update version for new release
* Tue Mar 26 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.3
- Changes since 6.0.2:
  * update version for new release
  * Update service-based shortcuts when service database changes (kde#479730,kde#483918)
  * Fix KHotkeys migration (kde#484063)
  * Also consider actions when querying for applications with shortcuts (kde#483214)
* Wed Mar 13 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.2
- Changes since 6.0.1:
  * Include all deprecated functions by default (kde#482712)
  * update version for new release
* Wed Mar  6 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.1
- Changes since 6.0.0:
  * update version for new release
* Mon Mar  4 2024 Christophe Marin <christophe@krop.fr>
- Add Provides/Obsoletes to replace Plasma 5
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0:
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.93.0:
  * plugins/xcb/kglobalaccel_x11: use new KKeyServer API (kde#478936)
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.93.0 (6.0 RC 2):
  * New bugfix release
  * See https://kde.org/announcements/megarelease/6/rc2/ for details
- Changes since 5.92.0:
  * globalshortcutsregistry: treat SysReq as Alt+Print (kde#386253)
  * Migrate command shortcuts from khotkeys
  * Only write non-default shortcuts during migration
  * Apply X-KDE-GlobalShortcutType also in loadFromService
  * Add migration helper to migrate dynamic shortcuts to desktop file based shortcuts
  * Fix old KF5-based desktop entries lingering in kglobalshortcutsrc
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.92.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Sat Jul  1 2023 Christophe Marin <christophe@krop.fr>
- Init kglobalacceld6
